<?php

namespace App\Http\Livewire\JobDescription;

use Livewire\Component;
use App\Helpers\LogHelper;
use Livewire\WithPagination;
use App\Models\JobDescription;

class JobDescriptionForm extends Component
{
    use WithPagination;

    public $name, $description, $job_description_id, $readonly;
    public $isOpen = 0, $number = 0;

    public function render()
    {
        $job_descriptions = JobDescription::orderBy('name', 'asc')->paginate(10);

        return view('livewire.job-description.job-description-form', ['job_descriptions' => $job_descriptions]);
    }

    public function create()
    {
        $this->resetInputFields();
        $this->openModal();
    }

    public function openModal()
    {
        $this->isOpen = true;
    }

    public function closeModal()
    {
        $this->isOpen = false;
        $this->resetInputFields();
    }

    private function resetInputFields()
    {
        $this->name = '';
        $this->description = '';
        $this->job_description_id = '';
        $this->readonly = '';
    }

    public function store()
    {
        $this->validate([
            'name' => 'required',
            'description' => 'required',
        ]);

        try {
            $job_description = JobDescription::updateOrCreate(['id' => $this->job_description_id], [
                'name' => $this->name,
                'description' => $this->description,
            ]);

            $message = $this->job_description_id ? __('messages.Job description') . "  $this->name " . __('messages.Updated Successfully.') : __('messages.Job description') . " $this->name " . __('messages.Created Successfully.');
            $messageLog = $this->job_description_id ? "Опис на работно место $this->name Успешно е Ажурирана" : "Опис на работно место $this->name Успешно е Креирана";
            session()->flash(
                'message',
                $message
            );
            $this->closeModal();
            $this->resetInputFields();

            $data = ['job_description' => $job_description];
            LogHelper::logInfo($messageLog, $data);
        } catch (\Exception $e) {
            $this->closeModal();
            $this->resetInputFields();

            $message = $e->getMessage();
            $data = ['job_name' => $this->name, 'error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);
        }
    }

    public function edit($id)
    {
        $job_description = JobDescription::findOrFail($id);
        $this->job_description_id = $id;
        $this->name = $job_description->name;
        $this->description = $job_description->description;

        $this->openModal();
    }

    public function show($id)
    {
        $job_description = JobDescription::findOrFail($id);
        $this->job_description_id = $id;
        $this->name = $job_description->name;
        $this->description = $job_description->description;

        $this->readonly = 'readonly';

        $this->openModal();
    }

    public function delete($id)
    {
        $job_description = JobDescription::findOrFail($id);
        $job_description_name = $job_description->name;
        $job_description->delete();
        $message = __('messages.Job description') . " $job_description_name " . __('messages.Deleted Successfully');
        session()->flash('message', $message);

        $messageLog = "Опис на работно место $job_description_name е успешно избришан/а";
        $data = ['job_description_name' => $job_description_name, 'message' => $message];
        LogHelper::logInfo($messageLog, $data);
    }
}
