<?php

namespace App\Http\Livewire\Modals;

use App\Helpers\LogHelper;
use Livewire\Component;

class DeleteModal extends Component
{
    public $modalHeading = '';
    public $modalMessage = '';
    public $showModal = false;
    public $model;

    protected $listeners = ['showModal'];

    public function showModal($modelType, $modelId, $modalHeading, $modalMessage)
    {
        $this->showModal = true;
        $this->model = $modelType::findOrFail($modelId);
        $this->modalHeading = $modalHeading;
        $this->modalMessage = $modalMessage;
    }

    public function destroy()
    {
        try {
            $modal = $this->model;
            $model_name = $modal->name;
            $modal->delete();
            //Only for live website (to create another record against deleted)
            //$this->model->factory()->create();
            // $this->emit('refreshComponent');
            $this->showModal = false;
            $this->emit('successAlert', __('messages.Deleted successfully'));


            $messageLog = "$model_name е избришан";
            $data = ['model' => $modal];
            LogHelper::logInfo($messageLog, $data);
            return redirect(request()->header('Referer'));

        } catch (\Exception $e) {
            $this->emit('successError', __('messages.Problem deleting, Try again later.'));
            $message = $e->getMessage();
            $data = ['role' => $this->model, 'error' => $e->getMessage()];
            LogHelper::logMessageError($message, $data);
        }

    }

    public function render()
    {
        return view('livewire.modals.delete-modal');
    }
}
