<?php

namespace App\Http\Livewire\Tables;

use App\Models\MnavLogs;
use Illuminate\Support\Facades\Auth;
use Mediconesystems\LivewireDatatables\Column;
use Mediconesystems\LivewireDatatables\DateColumn;
use Mediconesystems\LivewireDatatables\NumberColumn;
use Mediconesystems\LivewireDatatables\Http\Livewire\LivewireDatatable;

class LogDatatable extends LivewireDatatable
{
    public $model = MnavLogs::class;

    public $hideable = 'select';
    public $exportable = false;
    public $complex = false;
    public $persistComplexQuery = true;
    //    public $afterTableSlot = 'components.selected';

    public function builder()
    {
        //        return MnavLogs::query();
        return MnavLogs::query()->leftJoin('user_data', 'user_data.user_id', 'mnav_logs.created_by');
    }

    public function columns()
    {

        $user_name = Auth::user()->username;
        return [
            NumberColumn::name('id')
                ->label(__('messages.Id'))
                ->contentAlignCenter(),

            //            Column::name('level')
            //                ->label('Level')
            //                ->hideable()
            //                ->filterable(),

            Column::name('message')
                ->label(__('messages.Message'))
                ->defaultSort('asc')
                //                ->group('group1')
                ->searchable()
                ->hideable()
                ->filterable(),

            Column::name('level_name')
                ->label(__('messages.Level Name'))
                //                ->group('group1')
                ->searchable()
                ->hideable()
                ->filterable(),

            Column::name('context')
                ->defaultSort('asc')
                ->label(__('messages.Context'))
                //                ->searchable()
                ->hideable()
                //                ->filterable()
                ->hide()
                ->maxWidth(50),

            Column::raw("CASE
                WHEN user_data.first_name is not null
                THEN CONCAT(user_data.first_name, ' ', user_data.last_name)
                ELSE '$user_name'
                END
             AS Created by")
                ->label(__('messages.Created by'))
                ->searchable()
                ->hideable()
                ->filterable(),

            //           TimeColumn::name('created_at')
            //                ->label('Hours|Created at')
            //                ->filterable(),

            Column::raw("DATE_FORMAT (mnav_logs.created_at,'%H:%i:%s') AS " . __('messages.Time') . "")
                ->hideable()
                ->contentAlignCenter(),

            DateColumn::name('created_at')
                ->label(__('messages.Date|Created at'))
                ->filterable()
                ->contentAlignCenter(),

            Column::callback(['context'], function ($context) {
                return "
                <div x-data='{ open: false }' x-cloak>
                    <button
                        x-on:click='open = ! open'
                        class='inline-flex items-center text-white bg-blue-700 hover:bg-blue-800 focus:outline-none focus:ring-4 focus:ring-blue-300 font-medium rounded-full text-sm h-8 px-3 text-center dark:bg-blue-600 dark:hover:bg-blue-700 dark:focus:ring-blue-800'
                        type='button'
                        >
                        " . __('messages.View') . "
                    </button>

                    <div x-show='open' x-transition:enter='ease-out duration-300'
                        x-transition:enter-start='opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95'
                        x-transition:enter-end='opacity-100 translate-y-0 sm:scale-100'
                        x-transition:leave='ease-in duration-200'
                        x-transition:leave-start='opacity-100 translate-y-0 sm:scale-100'
                        x-transition:leave-end='opacity-0 translate-y-4 sm:translate-y-0 sm:scale-95'
                        class='relative bg-gray-100 rounded-lg px-4 pt-5 pb-4 overflow-hidden shadow-xl transform transition-all sm:max-w-lg sm:w-full sm:p-6 dark:bg-gray-700'>

                        <div class='w-full'>
                            <div class='mt-3 text-center'>
                                <div class='mt-2'>
                                    <div class='text-gray-700 dark:text-gray-300'>
                                        " . $context . "
                                    </div>
                                    <div class='flex justify-center'>
                                        <span class='mr-2'>
                                            <button x-on:click='open = false' class='inline-flex items-center text-white bg-gray-600 hover:bg-gray-700 focus:outline-none focus:ring-4 focus:ring-gray-300 font-medium rounded-full text-sm h-10 px-5 m-2 text-center dark:bg-gray-900 dark:hover:bg-gray-800 dark:focus:ring-gray-900'>
                                                " . __('messages.Close') . "
                                            </button>
                                        </span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                ";
            })
                ->unsortable()
                ->contentAlignCenter(),
        ];
    }
}
