<?php

namespace App\Http\Livewire\Tables;

use App\Models\Role;
use App\Models\User;
use Livewire\Component;
use Mediconesystems\LivewireDatatables\Column;
use Mediconesystems\LivewireDatatables\Http\Livewire\LivewireDatatable;

class UserDatatables extends LivewireDatatable
{

    public $model = User::class;
    public $route_edit = 'users.edit';
    public $hideable = 'select';
    public $exportable = true;
    public $exportcolumns;


    public function builder()
    {
        return User::query()->leftJoin('user_data', 'users.id', 'user_data.user_id');
    }

    public function columns()
    {
        $id = $this->id;
        return [

            Column::checkbox(),

            Column::name('username')
                ->label('Username')
                ->sortBy('username')
                ->filterable(),

            Column::name('email')
                ->label('Email')
                ->sortBy('email')
                ->filterable(),


            Column::name('user_data.first_name')
                ->label('First Name')
                ->sortBy('first_name')
                ->filterable(),

            Column::name('user_data.last_name')
                ->label('Last Name')
                ->sortBy('last_name')
                ->hideable()
                ->filterable(),

            //            Column::name('model_has_roles.model_type')
            //                ->label('Role')
            //                ->sortBy('Role')
            //                ->filterable(),

            Column::callback('id', 'getRole')
                ->filterable($this->roles->pluck('name'))
                ->label("Role"),

            Column::callback(['id', 'username'], function ($id, $username) {
                if ($this->exportcolumns) {
                    return $id;
                } else {
                    return view('livewire.tables.partials.user-admin-actions', ['id' => $id, 'username' => $username, 'route' => $this->route_edit]);
                }
            })->label('action')
                ->unsortable(),
        ];
    }

    public function getRolesProperty()
    {
        return Role::first();
    }

    public function getRole($id)
    {
        //         dd($this->activeSelectFilters);
        $users = User::find($id);
        //        return $user->roles->pluck('name');
        return $users->first_role_name();
    }

    public function getReports()
    {
        $mapped = $this->mapCallbacks(
            $this->getQuery()->get()
        );
    }

    //    public function render()
    //    {
    //        return view('livewire.tables.user-datatables');
    //    }
}
