<?php

namespace App\Jobs;

use App\Mail\LastReminder;
use App\Mail\UserInfo;
use Illuminate\Bus\Queueable;
use Illuminate\Support\Facades\Mail;
use Illuminate\Queue\SerializesModels;
use Illuminate\Queue\InteractsWithQueue;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Foundation\Bus\Dispatchable;
use App\Notifications\TaskReminderNotification;

class TaskReminderJob implements ShouldQueue
{
    use Dispatchable, InteractsWithQueue, Queueable, SerializesModels;

    /**
     * Create a new job instance.
     *
     * @return void
     */
    public $task;
    public $first_info;

    public function __construct($task, $first_info = null)
    {
        $this->task = $task;
        $this->first_info = $first_info;
    }

    /**
     * Execute the job.
     *
     * @return void
     */
    public function handle()
    {
        $users = $this->task->users->where('pivot.completed', false);

        foreach ($users as $user) {
            $task_info = [
                'task' => $this->task,
                'user' => $user,
            ];

            if ($this->first_info == 'reminder') {
                $user->notify(new TaskReminderNotification($task_info));
            } else if( $this->first_info == 'last_reminder'){
                Mail::to($user->email)->send(new LastReminder($user, $this->task));
            } else {
                Mail::to($user->email)->send(new UserInfo($user, $this->task));
            }
        }
        $this->job->getJobId();
    }
}
